Opinions

## Opinions for All Appellates

#### Step 1. Select or Change Court

Court:

#### Step 2. Search Opinions ...

Need Help?

#### ... OR View By Date

Year of Opinion:
Show all Opinions for Year Hide all Opinions
Click on a date below to view opinions.

WDOrder04-22-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
WD76933: Overview/Summary Priscella Gilley vs. Missouri Public Entity Risk Management Fund Author: Mark D. Pfeiffer, Judge Vote: Affirmed. Newton, p.J. and Martin, JJ., concur
WD76647: Overview/Summary State of Missouri vs. Stephen D. Wright Author: Karen King Mitchell, Judge Vote: Dismissed & remanded. Martin, P.J. and Pfeiffer, JJ., concur
WD76646: Overview/Summary State of Missouri vs. Travis Lovett Author: Joseph M. Ellis, Judge Vote: Dismissed & remanded. Welsh, C.J. and Rhodes, Sp. J., concur
WD76470: Overview/Summary Rocking H Trucking, LLC, and John Payne Harrison, IV vs. H.B.I.C., LLC, Michelle Alderson, and David Fenton, D.V.M. Author: Mark D. Pfeiffer, Judge Vote: Dismissed. Newton, P.J. and Martin, JJ., concur
WD76419: Overview/Summary Christopher Estes vs. Cole County of Missouri, et al Author: Cynthia L. Martin, Judge Vote: Affirmed. Newton, P.J. and Pfeiffer, JJ., concur
WD76356: Overview/Summary Ericka J. Sauvain, Amy Leigh Sauvain, by Next Friend Ericka J. Sauvain, and Bonnie S. Hughes vs. Acceptance Indemnity Insurance Company Author: Mark D. Pfeiffer, Judge Vote: Affirmed. Martin, P.J. and Mitchell, JJ., concur
WD76304: Overview/Summary State of Missouri vs. Henry L. Sutton, III Author: Cynthia L. Martin, Judge Vote: Affirmed. Newton, P.J. and Pfeiffer, JJ., concur
SDOrder-04-22-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
SD32777: JOHN MATTHEW CLARK, Petitioner-Respondent, v. DIRECTOR OF REVENUE, STATE OF MISSOURI, Respondent-Appellant. Author: Nancy Steffen Rahmeyer, Presiding Judge Vote: Affirmed. Scott, J., and Francis, Jr., C.J., Concur
ED99603: Overview/Summary Charles K. Moore, Appellant, vs. State of Missouri, Respondent. Author: Robert G. Dowd, Jr., J. Vote: REVERSED AND REMANDED. Lawrence E. Mooney, P.J. and Sherri B. Sullivan, J., concur.
ED99060: Overview/Summary Pulaski Bank, Respondent, vs. Nantucket Partners, L.C., a Missouri Limited Liability Company, and Julian Hess, Defendants, and Keith Barket, Appellant. Author: Kurt S. Odenwald, J. Vote: AFFIRMED. Mary K. Hoff, P.J., and Angela T. Quigless, J., Concur.
ED100569: Overview/Summary Captiva Lake Investments, LLC, a Missouri Limited Liability Company, and Cypress Condominium at the Lake of the Ozarks Association, Plaintiffs/Appellants, v. Ameristructure, Inc., a Missouri Corporation, and Stephen J. Sacco, Defendants/Respondents. Author: Sherri B. Sullivan, J. Vote: AFFIRMED. Lawrence E. Mooney, P.J., and Robert G. Dowd, Jr., J., concur.
ED100197: Overview/Summary David Darr, Appellant, vs. Roberts Marketing Group, LLC and Division of Employment Security, Respondents. Author: Karl A.W. DeMarce, S.J. Vote: REVERSED AND REMANDED. Robert M. Clayton III, C.J., and Gary M. Gaertner, Jr., J., concur.
SD32823: POPLAR BLUFF INTERNET, INC., Plaintiff/Appellant, vs. CITY OF POPLAR BLUFF, Defendant/Respondent. Author: William W. Francis, Jr., Chief Judge Vote: Affirmed. Rahmeyer, P.J., and Scott, J., Concur
SD32459: STATE OF MISSOURI, Plaintiff-Respondent, vs. JAMES CARL DUKE III, Defendant-Appellant. Author: Mary W. Sheffield, Judge Vote: Affirmed. Lynch, J., and Burrell, J., Concurs
SD32849: DONALD BRANDENBURG, Respondent, vs. TREASURER OF THE STATE OF MISSOURI, CUSTODIAN OF SECOND INJURY FUND, Appellant. Author: William W. Francis, Jr., Chief Judge Vote: Affirmed. Rahmeyer, P.J., and Scott, J., Concur
SD32109: STATE OF MISSOURI, Plaintiff-Respondent, vs. PETER D. HANSEN, Defendant-Appellant. Author: Nancy Steffen Rahmeyer, Presiding Judge Vote: Affirmed in Part, Reversed in Part, and Remanded with Directions. Francis, Jr., C.J., and Sheffield, J., Concur
SD32417: STATE OF MISSOURI, Plaintiff-Respondent, vs. CHRISTOPHER RYAN BEARD, Defendant-Appellant. Author: Don E. Burrell, Judge Vote: Affirmed. Rahmeyer, P.J., and Sheffield, J., Concur
WDOrder04-15-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
WD76589: Overview/Summary Brian Hauge and Susan Hanley vs. Trustees of Highlands of Chesterfield Author: James E. Welsh, Chief Judge Vote: Affirmed. Ellis, JJ. and Russell, Sp. J., concur
WD76552: Overview/Summary In the Matter of the Estate of M. Stanley Ginn, Deceased, Nancy Almond, Personal Representative (Administrator De Bonis Non) and Individually vs. Carrie Almond, et al Author: James E. Welsh, Chief Judge Vote: Affirmed. Ellis, JJ. and Russell, Sp. J., concur
WD76414: Overview/Summary Kwang H. Kim vs. Won Il Kim Author: James E. Welsh, Chief Judge Vote: Dismissed. Ellis, JJ. and Newton, JJ., concur
WD76228: Overview/Summary David A. Kline vs. State of Missouri Author: Alok Ahuja, Judge Vote: Affirmed. Witt, P.J. and Hardwick, JJ., concur
WD76102: Overview/Summary Central Bank of Kansas City vs. Donald Perry, et ux Author: Alok Ahuja, Presiding Judge Vote: Affirmed. Newton, JJ., and Gabbert, JJ., concur
WD75982: Overview/Summary Cindy Walden vs. Kenneth Smith and American Family Mutual Insurance Company Author: Cynthia L. Martin, Presiding Judge Vote: Affirmed. Pfeiffer, JJ., and Mitchell, JJ., concur
WD75944: Overview/Summary Deborah Barkley vs. McKeever Enterprises, Inc. D/B/A Price Chopper Author: Thomas H. Newton, Judge Vote: Affirmed. Ahuja, P.J., concurs Gabbert, JJ., dissents in a separate opinion
SDOrder-04-15-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
SC93742: Overview/Summary Jeffrey S. Amick, Appellant vs. Director of Revenue, Respondent. Author: Judge Richard B. Teitelman Vote: AFFIRMED. All concur.
SC93348: Overview/Summary State of Missouri, Respondent vs. Sharnique N. Jones, Appellant. Author: Judge Patricia Breckenridge Vote: AFFIRMED. All concur.
SC93162: Overview/Summary Minact, Inc., Respondent vs. Director of Revenue, Appellant. Author: Judge Richard B. Teitelman Vote: REVERSED AND REMANDED. All concur.
SC93132: Overview/Summary John Templemire, Appellant vs. W&M Welding, Inc., Respondent. Author: Judge George W. Draper III Vote: REVERSED AND REMANDED. Russell, C.J., Breckenridge, Stith and Teitelman, JJ., concur; Fischer, J., dissents in separate opinion filed; Wilson, J., concurs in opinion of Fischer, J.
SC93039: Overview/Summary Balloons Over the Rainbow, Inc., Appellant vs. Director of Revenue, Respondent. Author: Judge Patricia Breckenridge Vote: AFFIRMED IN PART AND REVERSED IN PART. All concur.
EDOrder-04-15-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
ED99938: Overview/Summary Robert H. Gurley, Movant/Appellant, vs. State of Missouri, Respondent. Author: Lisa S. Van Amburg, J. Vote: AFFIRMED. Patricia L. Cohen, Judge, and Philip M. Hess, Judge, concur.
ED99819: Overview/Summary State of Missouri, Respondent, vs. Stephen Caines, Appellant. Author: Robert G. Dowd, Jr., J. Vote: AFFIRMED. Lawrence E. Mooney, P.J., and Sherri B. Sullivan, J., concur.
ED99804: Overview/Summary Investors Alliance, LLC, Plaintiff/Respondent, vs. Inez Bordeaux, Defendant/Appellant. Author: Philip M. Hess, J. Vote: REVERSED AND REMANDED. Lisa S. Van Amburg, P.J., and Patricia L. Cohen, J., concur.
ED99782: Overview/Summary Mary L. Lehmann, et al., Respondents, vs. Bank of America, N.A., d/b/a U.S. Trust, Appellant. Author: Kurt S. Odenwald, J. Vote: AFFIRMED IN PART AND REVERSED AND REMANDED IN PART. Mary K. Hoff, P.J., and Angela T. Quigless, J., Concur.
ED99773: Overview/Summary Meagan Garland, Petitioner/Appellant, vs. Director, Family Support Division, Missouri Department of Social Services and Jeffrey Ruhl, Respondents. Author: Lisa S. Van Amburg, P.J. Vote: REVERSED AND REMANDED. Patricia L. Cohen, Judge, concurs. Gary M. Gaertner, Jr., Judge, dissents in separate opinion.
ED99701: Overview/Summary Marcus McCoy, Movant/Appellant, vs. State of Missouri, Respondent. Author: Philip M. Hess, J. Vote: AFFIRMED. Lisa S. Van Amburg, P.J., and Patricia L. Cohen, J., concur.
ED99089: Overview/Summary State of Missouri, Plaintiff/Respondent, vs. Kevin Murray, Defendant/Appellant. Author: Lisa S. Van Amburg, J. Vote: AFFIRMED. Patricia L. Cohen, Judge, and Philip M. Hess, Judge, concur.
ED100402: Overview/Summary Desiree Ridgell, Plaintiff/Appellant, vs. Mark McDermott and Karen McDermott, Defendants/Respondents. Author: Angela T. Quigless, J. Vote: REVERSED. Mary K. Hoff, P.J., and Kurt S. Odenwald, J., Concurs.
ED100117: Overview/Summary Aaron H. Johnson, Appellant, vs. State of Missouri, Respondent. Author: Roy L. Richter, P.J. Vote: DISMISSED IN PART; AFFIRMED IN PART. Clifford H. Ahrens, J., and Glenn A. Norton, J., concur.
ED100027: Overview/Summary Rolanda D. Pearson, Appellant, vs. Department of Employment Security, Respondent. Author: Lawrence E. Mooney, P.J. Vote: APPEAL DISMISSED AND CAUSE REMANDED WITH INSTRUCTIONS. Robert G. Dowd., Jr., J., and Sherri B. Sullivan, J., concur.
ED100001: Overview/Summary Xiaoyan Gu, Plaintiff/Appellant, vs. Da Hua Hu, and ACE INA Insurance Company Canada, Defendants/Respondents. Author: Philip M. Hess, J. Vote: REVERSED AND REMANDED. Lisa S. Van Amburg, P.J., and Patricia L. Cohen, J., concur.
SD32374 & SD32543 (Consolidated): THE BANK OF MISSOURI, Plaintiff-Respondent, vs. SOUTH CREEK PROPERTIES, LLC, HAMMER COLLECTIONS, LLC, MICHAEL and CHARLOTTE DEWLEY, Defendants-Appellants, and TREDWELL ENTERPRISES, INC., Third-Party Defendant-Respondent. Author: Mary W. Sheffield, Judge Vote: Affirmed. Bates, P.J., and Lynch, J., Concur
WDOrder04-08-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
WD77031: Overview/Summary State of Missouri ex rel Ideker, Inc. vs. The Honorable Jack Grate Author: Alok Ahuja, Judge Vote: Writ made absolute. Hardwick, P.J. and Mitchell, JJ., concur
WD76587: Overview/Summary Larry Nance (Deceased) vs. Maxon Electric, Inc., and National Surety Corp., c/o Fireman's Fund Insurance CO Author: Mark D. Pfeiffer, Judge Vote: Affirmed. Martin, P.J. and Mitchell, JJ., concur
WD76513: Overview/Summary Vincent Burton vs. SS Auto Inc. Author: Mark D. Pfeiffer, Judge Vote: Reversed & remanded with directions. Martin, P.J. and Mitchell, JJ., concur
WD76265: Overview/Summary Kevin Rowan vs. Coves North Homes Association Author: Victor C. Howard, Judge Vote: Reversed. Gabbert, P.J. and Newton, JJ., concur
WD76119: Overview/Summary Stacy Skiles Minze vs. Missouri Department of Public Safety, et al Author: Gary D. Witt, Presiding Judge Vote: Reversed & remanded. Hardwick, JJ. and Ahuja, JJ., concur
WD75983: Overview/Summary Mindy L. Schler and Cindy L. Schler vs. Coves North Homes Association Author: Victor C. Howard, Presiding Judge Vote: Reversed. Gabbert, P.J. and Newton, JJ., concur
WD75596: Overview/Summary State of Missouri vs. Deandre J. Key Author: Karen King Mitchell, Judge Vote: Affirmed. Martin, P.J. and Pfeiffer, JJ., concur
WD75051 with WD75081: Overview/Summary Developer Services Corporation vs. Triple J. Construction, Inc., et al; Brazin Excavating, Inc. Author: Alok Ahuja, Judge Vote: Affirmed. Welsh, C.J., Presiding and Messina, Sp. J., concur
SD32498: KIM FLORA, Petitioner-Respondent, vs. BRADLEY L. FLORA, Respondent-Appellant. Author: Don E. Burrell, Judge Vote: Affirmed. Bates, P.J., and Lynch, J., Concur
EDOrder-04-08-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
ED99897: Overview/Summary Lane House Construction, Inc., Respondent, vs. Doris Ogrowsky, Appellant. Author: Roy L. Richter, P.J. Vote: REVERSED AND REMANDED. Clifford H. Ahrens, J., and Glenn A. Norton, J., concur.
ED99727: Overview/Summary State of Missouri, Respondent, vs. Samuel Meeks, Appellant. Author: Robert G. Dowd., Jr., J. Vote: REVERSED AND REMANDED. Lawrence E. Mooney, P.J., and Sherri B. Sullivan, J., concur.
ED99269: Overview/Summary State of Missouri, Respondent, vs. Adam L. Steinmann, Appellant. Author: Patricia L. Cohen, J. Vote: AFFIRMED. Lisa S. Van Amburg, P.J., and Philip M. Hess, J., concur.
ED100856: Overview/Summary State of Missouri, Appellant, v. Joe L. Johnson, Respondent. Author: Gary M. Gaertner, Jr., J. Vote: REVERSED. Robert M. Clayton III, C.J., and Gary Dial, S.J., concur.
ED100424: Overview/Summary Christine A. Meissner, Appellant, vs. Jeffrey Schnettgoecke, Respondent. Author: Robert M. Clayton III, C.J. Vote: REVERSED AND REMANDED. Gary M. Gaertner, Jr., J., and Gary Dial, Sp.J., concur.
SD32775: MICHAEL D. BURNS, Appellant, vs. STATE OF MISSOURI, Respondent. Author: Daniel E. Scott, Judge Vote: Affirmed. Rahmeyer, P.J., and Francis, Jr., C.J., Concur
SD32776: AMANDA MEDLOCK and SAM MEDLOCK, Plaintiffs-Appellants, vs. ST. JOHN'S HEALTH SYSTEM, INC., and ST. JOHN'S CLINIC, INC., Defendants-Respondents. Author: Gary W. Lynch, Judge Vote: Affirmed. Burrell, J., and Sheffield, J., Concur
SDOrder-04-03-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
SD32636: STATE OF MISSOURI, Plaintiff-Respondent, vs. TENA D. CADY, Defendant-Appellant. Author: Gary W. Lynch, Judge Vote: Affirmed. Burrell, J., and Sheffield, J., Concur
WDOrder04-01-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
WD76395: Overview/Summary State of Missouri vs. Kathryn Avent Author: Joseph M. Ellis, Judge Vote: Affirmed. Howard, JJ., concurs Pfeiffer, JJ., dissents in a separate opinion
WD76321: Overview/Summary Greg White vs. Cole county, Missouri, et al Author: Gary D. Witt, Presiding Judge Vote: Affirmed. Hardwick, JJ., and Ahuja, JJ., concur
WD76191 and WD76192: Overview/Summary The Village at Deer Creek Homeowners Association, Inc. vs. Mid-Continent Casualty Company Author: Cynthia L. Martin, Presiding Judge Vote: Affirmed in part, vacated & modified in part. Pfeiffer, JJ., and Mitchell, JJ., concur
WD76147: Overview/Summary Greg Hall vs. Lowell Fox and Gina Fox, et al Author: Anthony Rex Gabbert, Presiding Judge Vote: Affirmed. Howard, JJ., Fischer, SpJ., concur
WD75850: Overview/Summary State of Missouri vs. Daniel A. Ivey Author: Cynthia L. Martin, Presiding Judge Vote: Affirmed. Pfeiffer, JJ., and Mitchell, JJ., concur
SC93649: Overview/Summary In the Interest of: J.A.R., D.K.R., and A.E.R., Children Under Seventeen Years of Age, Greene County Juvenile Office, Respondent vs. D.G.R., Appellant. Author: Judge Zel M. Fischer Vote: AFFIRMED. All concur.
EDOrder-04-01-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
ED99940: Overview/Summary Carrie Little, Appellant, vs. State of Missouri, Respondent. Author: Roy L. Richter, P.J. Vote: AFFIRMED. Clifford H. Ahrens, J., and Glenn A. Norton, J., concur.
ED99846: Overview/Summary Samson Desu, Plaintiff/Appellant, vs. Frederick Lewis, Defendant/Respondent. Author: Lisa S. Van Amburg, J. Vote: AFFIRMED IN PART, REVERSED IN PART AND REMANDED. Patricia L. Cohen, Judge, and Philip M. Hess, Judge, concur.
ED99841: Overview/Summary State of Missouri, Plaintiff/Respondent, v. Belvin L. Williams, Jr., Defendant/Appellant. Author: Sherri B. Sullivan, J. Vote: AFFIRMED. Robert M. Clayton III, C.J., and Angela T. Quigless, J., concur.
ED99769: Overview/Summary Ashley Janelle Lord, Respondent, vs. Directory of Revenue, State of Missouri, Appellant. Author: Kurt S. Odenwald, J. Vote: REVERSED AND REMANDED. Mary K. Hoff, P.J., and Angela T. Quigless, J., Concur.
ED99608: Overview/Summary State of Missouri, Respondent, vs. Douglas J. Howery, Appellant. Author: Kurt S. Odenwald, J. Vote: AFFIRMED. Mary K. Hoff, P.J., and Angela T. Quigless, J., Concur.
ED99519: Overview/Summary State of Missouri, Respondent, vs. Mark G. Jackson, Appellant. Author: Robert G. Dowd, Jr., J. Vote: AFFIRMED. Lawrence E. Mooney, P.J., and Sherri B. Sullivan, J., concur.
ED100014: Overview/Summary Vicki Armour-Mottaz, Claimant/Appellant, vs. Division of Employment Security, Respondent. Author: Mary K. Hoff, Judge Vote: AFFIRMED. Kurt S. Odenwald, Judge, and Angela T. Quigless, Judge, concur.
SD32887: In the Interest of: D.J.G., Minor, MISSOURI DEPARTMENT OF SOCIAL SERVICES, CHILDREN'S DIVISION, and, HOWELL COUNTY JUVENILE OFFICE, Petitioners-Respondents. vs. A.B., Natural Father, Respondent-Appellant. Author: Don E. Burrell, Judge Vote: Affirmed. Bates, P.J., and Lynch, J., Concur
SD32761: In The Estate Of: KENNETH SUMMER, JR., Respondent-Respondent, v. MISSOURI DEPARTMENT OF MENTAL HEALTH, Petitioner-Appellant. Author: Jeffrey W. Bates, Presiding Judge Vote: Reversed and Remanded. Lynch, J., and Burrell, J., Concur
SD32396: DOUG A. HOLMES, Respondent, vs. AMY F. HOLMES, Appellant. Author: Daniel E. Scott, Judge Vote: Affirmed in Part, Reversed in Part, and Remanded with Directions. Rahmeyer, P.J., Dissents in Separate Opinion, Francis, Jr., C.J., Concurs
SDOrder-03-28-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
SD32427: STATE OF MISSOURI, Plaintiff-Respondent, vs. SHELBY A. GAY, Defendant-Appellant. Author: Nancy Steffen Rahmeyer, Presiding Judge Vote: Affirmed. Scott, J., and Francis, Jr., C.J., Concur
SDOrder-03-27-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
SD32681: COLE ANDREW ANYAN, Petitioner-Respondent, vs. DIRECTOR OF REVENUE, STATE OF MISSOURI, Respondent-Appellant. Author: Mary W. Sheffield, Judge Vote: Reversed and Remanded with Instructions. Lynch, J., and Burrell, J., Concur
WDOrder03-25-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
WD76689: Overview/Summary Troy Marlin Hill vs. Director of Revenue Author: Cynthia L. Martin, Presiding Judge Vote: Affirmed. Pfeiffer, JJ. and Mitchell, JJ., concur
WD76353: Overview/Summary AG Processing, Inc. vs. KCP&L Greater Missouri Operations Company; Missouri Public Service Commission; Triumph Foods, LLC Author: Lisa White Hardwick, Judge Vote: Dismissed. Witt, P.J. and Ahuja, JJ., concur
WD76046 and WD76387 and WD76388: Overview/Summary MacKenzie Sheridan vs. Division of Employment Security Author: Gary D. Witt, Presiding Judge Vote: Reversed & remanded. Hardwick, JJ. and Ahuja, JJ., concur
WD75765: Overview/Summary State of Missouri vs. Chane Nutt Author: Thomas H. Newton, Judge Vote: Reversed & remanded. Gabbert, P.J. and Howard, JJ., concur
WD75688: Overview/Summary Taqwa Thompson vs. State of Missouri Author: Victor C. Howard, Judge Vote: Affirmed. Gabbert, P.J. and Newton, JJ., concur
SD32699 and SD32735 (Consolidated): THE EXECUTIVE BOARD OF THE MISSOURI BAPTIST CONVENTION, Plaintiff/Appellant, vs. WINDERMERE BAPTIST CONFERENCE CENTER, INC., JAMES L. HILL, RELIANCE TRUST COMPANY, NATIONAL CITY BANK OF THE MIDWEST, CONSOLIDATED MORTGAGE, INC., and FIRST AMERICAN TITLE MISSOURI AGENCY, INC., Defendants/Respondents. Author: William W. Francis, Jr., Chief Judge Vote: Affirmed. Rahmeyer, P.J. - Concurs Scott, J. - Concurs in Separate Opinion
SD32661 and SD32662: STATE OF MISSOURI, Plaintiff-Appellant, vs. KELLY ANN BURY, Defendant-Respondent. Author: Mary W. Sheffield, Judge Vote: Reversed and Remanded. Bates, P.J., and Burrell, J., Concur
SD32496: INTERNATIONAL DIVISION, INC., Plaintiff-Appellant, vs. DeWITT AND ASSOCIATES, INC., Defendant-Respondent. Author: Gary W. Lynch, Judge Vote: Reversed and Remanded. Bates, P.J., and Sheffield, J., Concur
SC93677: Overview/Summary In the Interest of: Q.A.H. Juvenile Officer, Respondent, C.W.M. and C.D.M., Respondents vs. M.H. (Mother), Appellant. Author: Chief Justice Mary R. Russell Vote: AFFIRMED. Breckenridge, Fischer, Stith, Draper and Wilson, JJ., concur; Teitelman, J., dissents in separate opinion filed.
SC93511: Overview/Summary Ronald Brehm, Appellant vs. Bacon Township, et al., Respondents. Author: Judge Laura Denvir Stith Vote: AFFIRMED. All concur.
SC93439: Overview/Summary St. Louis County, Missouri, et al., Appellants vs. State of Missouri, et al., Respondents. Author: Judge Richard B. Teitelman Vote: AFFIRMED IN PART AND REVERSED IN PART. All concur.
EDOrder-03-25-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
ED99837: Overview/Summary Reliance Bank, Plaintiff/Respondent, vs. Paramont Properties, LLC, and Keith Barket, Defendants/Appellants. Author: Philip M. Hess, J. Vote: AFFIRMED. Lisa S. Van Amburg, P.J. and Patricia L. Cohen, J., concur.
ED100357: Overview/Summary Collins-Camden Partnership, L.P., Plaintiff/Appellant, v. County of Jefferson, Missouri, and Jefferson County Council Members Don Bickowski, Renee Reuter, Bob Boyer, Charles Groeteke, Terri S. Kreitler, Cliff Lane and Kelly Waymon, Defendants/Respondents. Author: Sherri B. Sullivan, J. Vote: AFFIRMED. Lawrence E. Mooney, P.J., and Robert G. Dowd, Jr., J., concur.
ED100321: Overview/Summary Ardell Fields, Appellant, vs. State of Missouri, Respondent. Author: Clifford H. Ahrens, J. Vote: REVERSED AND REMANDED. Roy L. Richter, P.J., and Glenn A. Norton, J., concur.
ED100320: Overview/Summary Drury Company, Respondent/Cross-Appellant, vs. Missouri United School Insurance Counsel, Appellant, and Jackson R-2 School District, Cross-Respondent, and Warner-Nease-Bost Architects, Inc., Defendant. Author: Angela T. Quigless, J. Vote: AFFIRMED. Mary K. Hoff, P.J., and Kurt S. Odenwald, J., Concurs.
ED100308: Overview/Summary Lawrence Miller, Respondent, vs. Treasurer, State of Missouri, as Custodian of the Second Injury Fund, Appellant. Author: Clifford H. Ahrens, J. Vote: REVERSED AND VACATED. Roy L. Richter, P.J., and Glenn A. Norton, J., concur.
ED100063: Overview/Summary Todd C. Westergaard, Movant/Appellant, v. State of Missouri, Respondent/Respondent. Author: Sherri B. Sullivan, J. Vote: AFFIRMED. Lawrence E. Mooney, P.J., and Robert G. Dowd, Jr., J., concur.
SDOrder-03-24-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
SD32632: FARMERS INSURANCE CO., INC., and MID-CENTURY INSURANCE CO., Plaintiffs-Respondents, vs. ROBIN WILSON and DONALD BILLINGSLEY, Defendants-Appellants. Author: Gary W. Lynch, Judge Vote: Affirmed. Bates, P.J., and Sheffield, J., Concur
WDOrder03-18-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
SDOrder-03-18-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
EDOrder-03-18-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
ED99907: Overview/Summary State of Missouri, Respondent, vs. Nasir N. Ahmad, Appellant. Author: Roy L. Richter, P.J. Vote: DISMISSED. Clifford H. Ahrens, J., and Glenn A. Norton, J., concur.
ED99747: Overview/Summary Greg Haddock, Appellant, vs. State of Missouri, Respondent. Author: Kurt S. Odenwald, J. Vote: AFFIRMED. Mary K. Hoff, P.J., and Angela T. Quigless, J., Concur.
ED99203: Overview/Summary Kevin Plager, Appellant, vs. Tiffany Plager, Respondent. Author: Gary M. Gaertner, Jr., J. Vote: REVERSED AND REMANDED. Robert M. Clayton III, C.J., and Karl A.W. DeMarce, S.J., concur.
ED100452: Overview/Summary Lonnie Harris, Plaintiff/Respondent, v. Bi-State Development Agency, Defendant/Appellant. Author: Sherri B. Sullivan, J. Vote: AFFIRMED. Lawrence E. Mooney, P.J., and Robert G. Dowd, Jr., J., concur.
ED100191: Overview/Summary Shane Null, Respondent, vs. New Haven Care Center, Inc., Appellant, and Treasurer of Missouri as Custodian of the Second Injury Fund, Respondent. Author: Kurt S. Odenwald, J. Vote: AFFIRMED. Mary K. Hoff, P.J., and Angela T. Quigless, J., Concurs.
ED100137: Overview/Summary Tiffaney Hampton, Appellant, vs. Aerotek, Inc., and Division of Employment Security, Respondents. Author: Glenn A. Norton, J. Vote: APPEAL DISMISSED. Roy L. Richter, P.J. and Clifford H. Ahrens, J., concur.
SDOrder-03-17-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
SD33124: STATE OF MISSOURI EX REL. CHRIS KOSTER, Relator, vs. THE HONORABLE MARK FITZSIMMONS, ASSOCIATE CIRCUIT JUDGE OF GREENE COUNTY, AND STEVE HELMS, CIRCUIT CLERK, GREENE COUNTY CIRCUIT COURT, Respondents. Author: PER CURIAM Vote: Record and Writ of Habeas Corpus Quashed. Bates, P.J., Lynch, J., and Sheffield, J.
SD32478: RAYDIANT TECHNOLOGY, LLC, Appellant, v. FLY-N-HOG MEDIA GROUP, INC., Respondent. Author: Daniel E. Scott, Judge Vote: Affirmed. Rahmeyer, P.J., and Francis, Jr., C.J., Concur
SD32173: MARGARET ARD and ROBERT COMELY, Petitioners-Respondents, v. SHANNON COUNTY COMMISSION, Respondent-Appellant. Author: Jeffrey W. Bates, Presiding Judge Vote: Affirmed. Burrell, J., and Sheffield, J., Concur
SD32236: REJA LYNN COOPER, n/k/a REJA LYNN SPAENY, Petitioner-Appellant, vs. RONALD FRANCIS COOPER, Respondent-Respondent. Author: Mary W. Sheffield, Judge Vote: Affirmed. Bates, P.J., and Lynch, J., Concur
SD32758: ELLEN A. WISS and O. ELIZABETH CORBETT, Plaintiffs-Respondents, vs. GENE W. SPITZMILLER, Defendant/Trustee/Beneficiary-Appellant, and SHARON E. GUNN, Defendant/Trustee/Beneficiary-Respondent, and LINDA J. BRIDGER, Defendant/Beneficiary-Respondent. Author: Don E. Burrell, Judge Vote: Remanded with Directions. Lynch, J., and Sheffield, J., Concur
SD32757: ROBERTS HOLDINGS, INC., Plaintiff-Appellant, vs. BECCA'S BARKERY, INC., STEVEN KALCH, and REBECCA E. KALCH, Defendants-Respondents. Author: Don E. Burrell, Judge Vote: Affirmed. Bates, P.J., and Sheffield, J., Concur
WDOrder03-11-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
WD77056: Overview/Summary Rex A. Sinquefield and Travis Brown vs. Todd J. Jones and Missouri Roundtable for Life Author: Victor C. Howard, Judge Vote: Reversed & remanded. Welsh, C.J. and Newton, JJ., concur
WD76464: Overview/Summary The Salvation Army, Kansas and Western Missouri Division vs. Bank of America, et al Author: Mark D. Pfeiffer, Judge Vote: Affirmed. Martin, P.J. and Mitchell, JJ., concur
WD76155: Overview/Summary John Doe B.P. vs. Catholic Diocese of Kansas City-St. Joseph Author: Joseph M. Ellis, Judge Vote: Affirmed. Welsh, P.J., and Harman, Sp. J., concur
WD76128: Overview/Summary State of Missouri vs. Nelson E. Hopkins Author: Karen King Mitchell, Judge Vote: Dismissed. Martin, P.J. and Pfeiffer, JJ., concur
WD76008 Consolidated with 76050: Overview/Summary James F. Conant, M.D. and Missouri Doctors Mutual Insurance Company vs. Department of Insurance, Financial Institutions and Professional Registration, John M. Huff, Director of Department of Insurance, Financial Institutions and Professional Registration, and Frederick G. Heese, Chief Financial Examiner and Director of the Division of Insurance Company Regulation of the Department of Insurance, Financial Institutions and Professional Registration Author: Anthony Rex Gabbert, Presiding Judge Vote: Reversed & remanded. Hardwick, JJ. and Newton, JJ., concur
WD75934: Overview/Summary Tricia Barron vs. Division of Employment Security Author: Alok Ahuja, Judge Vote: Reversed & remanded. Witt, P.J. and Hardwick, JJ., concur
WD75863: Overview/Summary Tylicee S. Greene vs. Alliance Automotive, Inc. D/B/A JD Byrider and AutoBanc-2 Corporation D/B/A CNAC Author: Anthony Rex Gabbert, Judge Vote: Affirmed. Howard, P.J. and Ellis, JJ., concur
SD32794: DEBORAH K. MORRIS, Personal Representative of the Estate of Steven W. Groves, Deceased, Appellant, vs. TRUST COMPANY OF THE OZARKS, as Trustee of the William and Kathryn Groves Trust Under Agreement dated July 2, 1991, as amended, Maurice Houghton, Martha Rains, Louise Zook, Evangeline Skelton, John Jack Munsey, Park University, and Fitchburg State College, Respondents. Author: Daniel E. Scott, Judge Vote: Affirmed. Lynch, J., and Bates, P.J., Concur
SD32627: KATHY LYNN SHAFER, Petitioner/Appellant, vs. DANIEL DEL SHAFER, Respondent/Respondent. Author: William W. Francis, Jr., Chief Judge Vote: Reversed and Remanded in Part with Directions; Affirmed in Part. Rahmeyer, P.J., and Scott, J., Concur
SD32326: BRYAN LEE STEELE, Petitioner/Respondent, vs. JUDY ANN STEELE, Respondent/Appellant. Author: William W. Francis, Jr., Chief Judge Vote: Affirmed. Rahmeyer, P.J., and Scott, J., Concur
SC93606: Overview/Summary In the Matter of Lonnie Brockmire, Deceased. Author: Judge Paul C. Wilson Vote: REVERSED. All concur.
SC93331: Overview/Summary AAA Laundry & Linen Supply Co., Respondent vs. Director of Revenue, Appellant. Author: Judge Paul C. Wilson Vote: REVERSED AND REMANDED. All concur.
SC93238: Overview/Summary Karen M. Brown, Respondent vs. Anthony T. Brown, Appellant. Author: Per Curiam Vote: AFFIRMED. All concur.
SC93083: Overview/Summary Union Electric Co. d/b/a Ameren Missouri, Appellant vs. Director of Revenue, Respondent. Author: Judge Laura Denvir Stith Vote: AFFIRMED. All concur.
EDOrder-03-11-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
ED99619: Overview/Summary Jeffrey G. Thurman, Appellant, vs. State of Missouri, Respondent. Author: Kurt S. Odenwald, J. Vote: AFFIRMED. Mary K. Hoff, P.J., and Angela T. Quigless, J., Concur.
ED99517: Overview/Summary Henry Frazier, Appellant, vs. State of Missouri, Respondent. Author: Patricia L. Cohen, J. Vote: AFFIRMED. Lisa S. Van Amburg, P.J., and Gary M. Gaertner, Jr., J., concur.
ED99366: Overview/Summary State of Missouri, Respondent, v. Cemon Byrd, Appellant Author: Gary M. Gaertner, Jr., J. Vote: AFFIRMED. Robert M. Clayton III, C.J., and Karl A.W. DeMarce, S.J., concur.
ED99057: Overview/Summary Anastasia M. Hoffman, Respondent/Cross-Appellant, vs. Richard W. Hoffman, Appellant. Author: Patricia L. Cohen, J. Vote: AFFIRMED. Lisa S. Van Amburg, P.J., and Gary M. Gaertner, Jr., J., concur.
ED98906: Overview/Summary State of Missouri, Respondent, vs. George Dewey McCleary, III, Appellant. Author: Lawrence E. Mooney, P.J. Vote: JUDGMENT AFFIRMED. Robert G. Dowd, Jr., J., and Sherri B. Sullivan, J., concur.
SDOrder-03-10-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
SD32382 and SD32406 (Consolidated): GRAU CONTRACTING, INC., Plaintiff, vs. CAPTIVA LAKE INVESTMENTS, LLC, Appellant/Cross-Respondent, MISSOURI BUILDERS SERVICE, INC., Respondent/Cross-Appellant, QUESTEC CONTRUCTORS, INC., BUTLER SUPPLY, INC., HOUSE OF CARPET, INC., and MEYER ELECTRIC CO., INC., Respondents. Author: Daniel E. Scott, Judge Vote: Affirmed. Rahmeyer, P.J., and Francis, Jr., C.J., Concur
SD31479: TERRY A. GUENGERICH and LORRAINE GUENGERICH, Plaintiffs-Appellants, v. KAYLA BARKER and CLARENCE EDWARD HIGGINS, JR., Defendants-Respondents. Author: Jeffrey W. Bates, Judge Vote: Affirmed as Modified. Barney, Sr., J. - Concurs Scott, J. - Concurs in Part and Dissents in Part (Separate Opinion)
SDOrder-03-05-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
SD32688: 2 MIKES, INC., Plaintiff-Appellant, vs. TURNING LEAF PROPERTIES, LLC, Defendant-Respondent. Author: Don E. Burrell, Judge Vote: Affirmed. Bates, P.J., and Sheffield, J., Concur
WDOrder03-04-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
WD76551: Overview/Summary In The Interest Of T.J.P., Jr. Juvenile Officer vs. T.L. (Mother) Author: Karen King Mitchell, Judge Vote: Affirmed. Martin, P.J., and Pfeiffer, JJ., concur
WD76396: Overview/Summary Charles Rademan vs. Al Scheppers Motor Company and Division of Employment Security Author: Anthony Rex Gabbert, Presiding Judge Vote: Dismissed. Howard, JJ., and Newton, JJ., concur
WD76381: Overview/Summary C.I.A. vs. T.E. Author: Victor c. Howard, Judge Vote: Dismissed as moot. Gabbert, P.J., and Newton, JJ., concur
WD76303: Overview/Summary Juvenile Officer W.J., S.C. and C.M. vs. A.S.M. (Mother) Author: Cynthia L. Martin, Presiding Judge Vote: Affirmed. Pfeiffer, JJ., and Mitchell, JJ., concur
WD75698: Overview/Summary State of Missouri vs. Joseph B. Sprofera Author: Joseph M. Ellis,Judge Vote: Affirmed in part, reversed & remanded in part. Welsh, C.J., and Witt, JJ., concur
WD75669: Overview/Summary Kenneth G. Middleton vs. State of Missouri Author: Anthony Rex Gabbert, Judge Vote: Affirmed. Ahuja, P.J., and Newton, JJ., concur
SD32564: In Re the Marriage of: SCOTT D. YONKER, and VALERIE K. YONKER, SCOTT DAMIAN YONKER, Petitioner-Respondent, vs. VALERIE KAY YONKER, n/k/a VALERIE KAY BOYCE, Respondent-Appellant. Author: Don E. Burrell, Judge Vote: Affirmed in Part, Reversed in Part, and Remanded with Instructions. Bates, P.J., and Lynch, J., Concur
EDOrder-03-04-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
ED99909: Overview/Summary Arbab Adum, Respondent, vs. St. Louis Metropolitan Police Department, et al., Appellant. Author: Robert G. Dowd, Jr., J. Vote: REVERSED. Lawrence E. Mooney, P.J., concurs in result. Sherri B. Sullivan, J., concurs.
ED99852: Overview/Summary Biri M. Blevins, John T. Busey, and Charles W. Jones, Appellants, vs. American Family Mutual Insurance Company and Janey Foust, Respondents. Author: Robert M. Clayton III, C.J. Vote: REVERSED AND REMANDED IN PART AND AFFIRMED IN PART. Roy L. Richter, J., and Gary M. Gaertner, Jr., J., concur.
ED99492: Overview/Summary Tracy M. Atkinson, Respondent, v. Douglas D. Atkinson, Appellant. Author: Clifford H. Ahrens, J. Vote: REVERSED AND REMANDED. Roy L. Richter, P.J., and Glenn A. Norton, J., concur.
ED99261: Overview/Summary State of Missouri, Respondent, vs. Brenda Churchill, Appellant. Author: Kurt S. Odenwald, J. Vote: AFFIRMED. Angela T. Quigless, J., Concurs in result only and Mary K. Hoff, P.J., Dissents in separate opinion.
ED99128: Overview/Summary Richard Simmons, Appellant, vs. State of Missouri, Respondent. Author: Roy L. Richter, P.J. Vote: AFFIRMED. Clifford H. Ahrens, J., and Glenn A. Norton, J., concur.
ED100929: Overview/Summary State of Missouri ex rel. Jason O. Salm, Relator, vs. The Honorable Chris Kunza Mennemeyer, Respondent. Author: Glenn A. Norton, J. Vote: PRELIMINARY ORDER IN MANDAMUS MADE PERMANENT. Sherri B. Sullivan, J., and Patricia L. Cohen, J., concur.
ED100276: Overview/Summary Morion S. Dawson, Appellant, v. State of Missouri, Respondent. Author: Gary M. Gaertner, Jr., J. Vote: AFFIRMED. Robert M. Clayton III, C.J., and Karl A.W. DeMarce, S.J., concur.
ED100064: Overview/Summary State of Missouri, Respondent, v. Keith Stubblefield, Appellant. Author: Gary M. Gaertner, Jr., J. Vote: AFFIRMED. Robert M. Clayton III, C.J., and Karl A.W. DeMarce, S.J., concur.
WDOrder02-25-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
WD76584: Overview/Summary Jenn Baier vs. Darden Restaurants, et al Author: Cynthia L. Martin, Presiding Judge Vote: Affirmed. Witt, JJ., and Fischer, Sp. J., concur
WD75582: Overview/Summary State of Missouri vs. Maura Celis-Garcia Author: Gary Witt, Presiding Judge Vote: Affirmed. Hardwick, JJ., and Ahuja, JJ., concur
WD74429: Overview/Summary City of Harrisonville vs. McCall Service Stations d/b/a Big Tank Oil, et al; The Missouri Petroleum Storage Tank Insurance Func Author: Alok Ahuja, Presiding Judge Vote: Affirmed as modified. Pfeiffer, JJ., and Gabbert, JJ., concur
WD74285: Overview/Summary State of Missouri vs. Trent L. Williams Author: Mark D. Pfeiffer, Judge Vote: Affirmed in part, reversed in part & remanded. Martin, P.J., and Mitchell, JJ., concur
SC93404: Overview/Summary Naylor Senior Citizens Housing, LP, et al., Appellants, and John Dilks, Plaintiff vs. Sides Construction Company, Inc., et al., Respondents. Author: Judge Paul C. Wilson Vote: AFFIRMED. All concur.
SC93361: Overview/Summary Melissa Coday, Appellant vs. Division of Employment Security, Respondent. Author: Judge Paul C. Wilson Vote: VACATED AND REMANDED. All concur.
SC93182: Overview/Summary Central Trust and Investment Company, Appellant vs. SignalPoint Asset Management, LLC, Respondent. Author: Judge Zel M. Fischer Vote: AFFIRMED. Breckenridge, Stith, Draper, Wilson and Teitelman, JJ., and Bickel, Sp.J., concur. Russell, C.J., not participating.
SC93120: Overview/Summary Clayton Dean Price, Respondent vs. State of Missouri, Appellant. Author: Judge Paul C. Wilson Vote: REVERSED. Russell, C.J., Breckenridge and Fischer, JJ., concur; Stith, J., dissents in separate opinion filed; Draper and Teitelman, JJ., concur in opinion of Stith, J.
EDOrder-02-25-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
ED99914: Overview/Summary Karl Gardner, Appellant, vs. MERS/Missouri Goodwill Industries, and Division of Employment Security, Respondents. Author: Glenn A. Norton, J. Vote: APPEAL DISMISSED. Roy L. Richter, P.J. and Clifford H. Ahrens, J., concur.
ED99869: Overview/Summary Jonathan Joyner, Appellant, vs. State of Missouri, Respondent. Author: Robert G. Dowd, Jr., J. Vote: AFFIRMED. Lawrence E. Mooney, P.J. and Sherri B. Sullivan, J., concur.
ED99868: Overview/Summary John J. Smith, Appellant, vs. Lora J. Smith, Respondent. Author: Robert G. Dowd, Jr., J. Vote: DISMISSED. Lawrence E. Mooney, P.J. and Sherri B. Sullivan, J., concur.
ED99858: Overview/Summary Danin Gray, Appellant, vs. Division of Employment Security, Respondent. Author: Robert G. Dowd, Jr., J. Vote: AFFIRMED. Lawrence E. Mooney, P.J. and Sherri B. Sullivan, J., concur.
ED99724: Overview/Summary Gavin Hauk, Respondent, vs. Scotland County Commission and It's Commissioners: Charles Harris, Jr., David Wiggins and Danette Clatt in their Official Capacities, Appellants. Author: Robert M. Clayton III, C.J. Vote: WE AFFIRM. Clifford H. Ahrens, J. and Gary M. Gaertner, Jr., J., concur.
ED99651: Overview/Summary Antonio Jackson, Appellant, vs. State of Missouri, Respondent. Author: Kurt S. Odenwald, J. Vote: AFFIRMED. Mary K. Hoff, P.J., and Angela T. Quigless, J., Concur.
ED99566: Overview/Summary A.L.C., Respondent, vs. D.A.L., Appellant. Author: Glenn A. Norton, J. Vote: REVERSED AND REMANDED. Roy L. Richter, P.J. and Clifford H. Ahrens, J., concur.
ED99440: Overview/Summary Manuel Burgess, Appellant, vs. State of Missouri, Respondent. Author: Patricia L. Cohen, J. Vote: AFFIRMED. Lisa S. Van Amburg, P.J., and Philip M. Hess, J., concur.
ED99033: Overview/Summary State of Missouri, Respondent, vs. Paul Curtis White, Appellant. Author: Robert G. Dowd, Jr., J. Vote: AFFIRMED. Lawrence E. Mooney, P.J. and Sherri B. Sullivan, J., concur.
ED98978: Overview/Summary State of Missouri, Respondent, vs. Darion Jordan Ivy, Appellant. Author: Kurt S. Odenwald, J. Vote: AFFIRMED. Mary K. Hoff, P.J., and Angela T. Quigless J., Concur.
ED100826: Overview/Summary State of Missouri ex rel. Ernest Kizer, Relator, vs. Honorable Chris Kunza Mennemeyer, Judge of the Circuit Court of Lincoln County, Missouri, Respondent. Author: Lawrence E. Mooney, P.J. Vote: PRELIMINARY ORDER IN MANDAMUS MADE PERMANENT. Glenn A. Norton, J. and Gary M. Gaertner, Jr., J., concur.
ED100782: Overview/Summary State of Missouri ex rel. Michael Lovelace, Relator, vs. Honorable Chris Kunza Mennemeyer, Judge of the Circuit Court of Lincoln County, Missouri, Respondent. Author: Lawrence E. Mooney, P.J. Vote: PRELIMINARY ORDER IN MANDAMUS MADE PERMANENT. Glenn A. Norton, J. and Gary M. Gaertner, Jr., J., concur.
ED100153: Overview/Summary Romell Bates, Appellant, vs. State of Missouri, Respondent. Author: Robert G. Dowd, Jr., J. Vote: AFFIRMED. Lawrence E. Mooney, P.J. and Sherri B. Sullivan, J., concur.
ED100074: Overview/Summary John F. Maness, Respondent, vs. City of De Soto and Missouri Intergovernmental Risk Management Association, Appellants, and Treasurer of Missouri as Custodian of the Second Injury Fund, Respondent. Author: Angela T. Quigless, J. Vote: AFFIRMED. Mary K. Hoff, P.J. and Kurt S. Odenwald, J., Concurs.
SD32710: LEE HARRELL, Movant-Appellant, v. STATE OF MISSOURI, Respondent-Respondent. Author: Jeffrey W. Bates, Presiding Judge Vote: Affirmed. Lynch, J., and Burrell, J., Concurs
SD32873 and SD32874 (Consolidated): In the Interest of: A.A.R., and A.N.R., Minors, GREENE COUNTY JUVENILE OFFICE, Petitioner-Respondent, vs. M.S.R., Mother, Respondent-Appellant. Author: Don E. Burrell, Judge Vote: Affirmed. Bates, P.J., and Lynch, J., Concurs
SD32778: CINDY SILLYMAN, Plaintiff-Appellant, vs. DAVID O. BARBE, M.D., and ST. JOHN'S PHYSICIANS AND CLINICS, INC., d/b/a ST. JOHN'S CLINIC, Defendants-Respondents. Author: Mary W. Sheffield, Judge Vote: Affirmed. Bates, P.J., and Lynch, J., Concurs
WDOrder02-18-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
WD76644: Overview/Summary Jay Wolfe Used Cars of Blue Springs, LLC D/B/A Jay Wolfe Auto Outlet vs. Tyrell C. Jackson and Liane K. Jackson, on Their Own Behalf and on Behalf of All Others Similarly Situated Author: Cynthia L. Martin, Presiding Judge Vote: Affirmed. Witt, JJ., and Fischer, Sp. J., concur
WD75335: Overview/Summary State of Missouri vs. Antonio West Author: Gary D. Witt, Judge Vote: Affirmed. Martin, P.J., and Fischer, Sp. J.,, concur
SDOrder-02-18-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
SD32741: SKAGGS REGIONAL MEDICAL CENTER, Respondent, vs. TAMMIE M. POWERS, Appellant. Author: Daniel E. Scott, Judge Vote: Affirmed. Rahmeyer, P.J., and Francis, Jr., C.J., Concurs
SD32293: STATE OF MISSOURI, Plaintiff-Respondent, vs. BOBBY GLEN ROST, Defendant-Appellant. Author: Nancy Steffen Rahmeyer, Presiding Judge Vote: Affirmed. Scott, J., and Francis, Jr., C.J., Concurs
ED99950: Overview/Summary Trudy A. Zahn, Appellant/Cross-Respondent, v. Charles W. Zahn, Respondent/Cross-Appellant. Author: Gary M. Gaertner, Jr., J. Vote: AFFIRMED IN PART AND REVERSED AND REMANDED IN PART. Lisa S. Van Amburg, P.J. and Patricia L. Cohen, J., concur.
ED99779: Overview/Summary Larry Abt, Claimant/Appellant, vs. Mississippi Lime Company, Employer/Respondent, and Treasurer of Missouri as Custodian of the Second Injury Fund, Additional Party/Respondent. Author: Lawrence E. Mooney, P.J. Vote: REVERSED AND REMANDED IN PART AND AFFIRMED IN PART. Robert G. Dowd, Jr., J., and Sherri B. Sullivan, J., concur.
ED99712: Overview/Summary State of Missouri, Respondent, vs. Leonard M. Slocum, Appellant. Author: Patricia L. Cohen, J. Vote: AFFIRMED. Lisa S. Van Amburg, P.J., and Philip M. Hess, J., concur.
ED99707: Overview/Summary John Doe, Respondent, vs. Col. Daniel Isom, et al., Appellants. Author: Roy L. Richter, P.J. Vote: REVERSED AND REMANDED. Clifford H. Ahrens, J., and Glenn A. Norton, J., concur.
ED99427: Overview/Summary State of Missouri, Plaintiff/Respondent, vs. Claude Dale Brooks, Defendant/Appellant. Author: Lisa S. Van Amburg, J. Vote: VACATED AND REMANDED. Patricia L. Cohen, Judge, concurs. Gary M. Gaertner, Jr., Judge, dissents in separate opinion.
ED100251: Overview/Summary Stacey L. Blackshear, Claimant/Respondent, v. Adecco, Employer/Respondent, and American Home Assurance Company c/o Broadspire Services, Inc., Respondent, and Treasurer of the State of Missouri, Custodian of the Second Injury Fund, Appellant. Author: Sherri B. Sullivan, J. Vote: AFFIRMED. Lawrence E. Mooney, P.J., and Robert G. Dowd, Jr., J., concur.
ED100044: Overview/Summary Thomas Binkley, Harlene J. Binkley, Roland E. Sturhahn, and Susan J. Sturhahn, Appellants, vs. American Equity Mortgage, Inc., Respondent. Author: Patricia L. Cohen, J. Vote: AFFIRMED. Lisa S. Van Amburg, P.J., and Gary M. Gaertner, Jr., J., concur.
SD32542: STATE OF MISSOURI, Plaintiff-Respondent vs. DANNY K. THOMAS, Defendant-Appellant Author: Judge Mary W. Sheffield Vote: Affirmed. Lynch, J., and Burrell, J., Concur.
SDOrder-02-13-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
SDOrder-02-11-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
SD31205: JAMES R. BAKER and LINDA BAKER, Plaintiffs-Appellants, and CHARLES E. HIGHTOWER, DIANE HIGHTOWER, MARVIN D. GRIFFITH, MARILYN SUE GRIFFITH, and THE UNKNOWN HEIRS, DEVISEES, GRANTEES, SUCCESSORS AND ASSIGNS OF JAMES ELLIS THOMPSON, JR, DECEASED, Plaintiffs, v. WALNUT BOWLS, INC., Defendant-Respondent. Author: Jeffrey W. Bates, Judge Vote: Reversed and Remanded. Barney, Sr., J., and Scott, J., Concur
EDOrder-02-11-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
ED99989: Overview/Summary Bank of America, N.A., Respondent, vs. Ronald Duff d/b/a Ron Duff Video Productions and Jo Duff, Appellants. Author: Angela T. Quigless, J. Vote: AFFIRMED. Mary K. Hoff, P.J., and Kurt S. Odenwald, J., Concurs.
ED99945: Overview/Summary Cheryl Hirsch, Employee/Appellant, v. Convergys Customer Management Group, Inc., Employer/Respondent, and Division of Employment Security, Respondent/Respondent. Author: Sherri B. Sullivan, J. Vote: AFFIRMED. Lawrence E. Mooney, P.J., and Robert G. Dowd, Jr., J., concur.
ED99916: Overview/Summary Christopher J. Ivory, Movant/Appellant, vs. State of Missouri, Respondent. Author: Mary K. Hoff, P.J. Vote: AFFIRMED. Kurt S. Odenwald, J., and Angela T. Quigless, J., Concur.
ED99615: Overview/Summary James Moore, Appellant, vs. State of Missouri, Respondent. Author: Roy L. Richter, P.J. Vote: DISMISSED. Clifford H. Ahrens, J., and Glenn A. Norton, J., concur.
ED99555: Overview/Summary State of Missouri, Plaintiff/Respondent, v. Robert Baker, Defendant/Appellant. Author: Sherri B. Sullivan, J. Vote: AFFIRMED. Lawrence E. Mooney, P.J., and Robert G. Dowd, Jr., J., concur.
ED99531: Overview/Summary State of Missouri, Plaintiff/Respondent, v. Chris Edward Reed, Defendant/Appellant. Author: Sherri B. Sullivan, J. Vote: AFFIRMED. Lawrence E. Mooney, P.J., and Robert G. Dowd, Jr., J., concur.
ED99452: Overview/Summary Genevieve-Anne Gaudreau, Respondent, vs. Richard A. Barnes, Appellant. Author: Roy L. Richter, P.J. Vote: AFFIRMED. Clifford H. Ahrens, J., and Glenn A. Norton, J., concur.
ED99319: Overview/Summary John T. Haidul, Appellant, vs. State of Missouri, Respondent. Author: Angela T. Quigless, J. Vote: AFFIRMED. Mary K. Hoff, P.J., and Kurt S. Odenwald, J., Concurs.
ED98875: Overview/Summary State of Missouri, Plaintiff/Respondent, vs. Christopher Sonnier, Defendant/Appellant. Author: Lisa S. Van Amburg, J. Vote: AFFIRMED. Patricia L. Cohen, J., and Philip M. Hess, J., concur.
ED98171: Overview/Summary Richard Burton and Patricia Burton, Appellants, vs. Janice Klaus, Respondent. Author: Kurt S. Odenwald, J. Vote: DISMISSED. Mary K. Hoff,P.J., and Angela T. Quigless, J., Concur.
SD32827: MARLENE STEWART, Respondent vs. CLINT ZWIEFEL, TREASURER OF THE STATE OF MISSOURI AS CUSTODIAN OF THE SECOND INJURY FUND, Appellant Author: Judge Daniel E. Scott Vote: Affirmed. Rahmeyer, P.J., and Francis, C.J., concur
SD32774: JENNIFER DEARBORN, Claimant-Respondent vs. GREAT SOUTHERN FINANCIAL CORPORATION, Employer-Appellant, DIVISION OF EMPLOYMENT SECURITY, Respondent Author: Judge Gary W. Lynch Vote: Affirmed. Bates, P.J., and Burrell, J., Concur
SD32470: RHONDA PARROTT, as Surviving Spouse of JAMES KELSO PARROT, Deceased, and Individually, Plaintiff-Respondent, vs. SEVERS TRUCKING, LLC, and BRANDON G. BLACK, Defendants-Appellants. Author: Gary W. Lynch, Judge Vote: Reversed and Remanded. Bates, P.J., and Burrell, J., Concur
SD32626 and SD32663: RICKY LEE GRIFFITTS, Plaintiff-Respondent, vs. JAMES M. CAMPBELL, Defendant-Respondent, and BNSF RAILWAY COMPANY and OLD REPUBLIC INSURANCE COMPANY, Intervenors-Appellants. Author: Nancy Steffen Rahmeyer, Presiding Judge Vote: Affirmed. Scott, J., and Francis, Jr., C.J., Concur
SD32633: MARK HOPWOOD and MARY HOPWOOD, Plaintiffs-Respondents, v. CITIFINANCIAL, INC. and ZACHREY B. BOULWARE, Defendants-Appellants. Author: Jeffrey W. Bates, Presiding Judge Vote: Affirmed. Burrell, J., and Sheffield, J., Concur
SD32475: TOM M. ROBERTSON, IAFF LOCAL 2618, ADAM GRINES, LARIN TRENARY, and DANIEL JOBE, Plaintiffs-Respondents, vs. POLICE AND FIREMEN'S PENSION PLAN OF CITY OF JOPLIN, TRUSTEES OF POLICE AND FIREMEN'S PENSION PLAN OF CITY OF JOPLIN, and CITY OF JOPLIN, MISSOURI, Defendants-Appellants. Author: Don E. Burrell, Judge Vote: Reversed and Remanded with Instructions. Lynch, J., and Sheffield, J., Concur
WDOrder02-04-2013: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
WD76383: Overview/Summary Tracy Gunn vs. Division of Employment Security Author: Thomas H. Newton, Judge Vote: Affirmed. Ahuja, P.J., and Gabbert, JJ., concur
WD76338: Overview/Summary Dawn Stewart vs. Division of Employment Security Author: Anthony Rex Gabbert, Judge Vote: Reversed & remanded. Ahuja, P.J., and Newton, JJ., concur
WD76197: Overview/Summary Shana Medley vs. Division of Employment Security Author: Anthony Rex Gabbert, Presiding Judge Vote: Dismissed. Howard, JJ., and Newton, JJ., concur
WD75874: Overview/Summary Michael W. Schlax vs. State of Missouri Author: Lisa White Hardwick, Judge Vote: Affirmed. Witt, P.J., and Ahuja, JJ., concur
SC93618: Overview/Summary Arthur L. LeBeau, Jr., et al., Appellants vs. Commissioners of Franklin County, Missouri, Respondents. Author: Judge Zel M. Fischer Vote: REVERSED AND REMANDED. All concur.
SC93195: Overview/Summary City of Kansas City, Missouri, Respondent vs. Karen Chastain, et al., Appellants. Author: Judge Richard B. Teitelman Vote: REVERSED AND REMANDED. Russell, C.J., Breckenridge, Stith and Draper, JJ., concur; Wilson, J., concurs in separate opinion filed; Fischer, J., concurs in opinion of Wilson, J.
SC93134: Overview/Summary Jodie Nevils, Appellant vs. Group Health Plan, Inc., and ACS Recovery Services, Inc., Respondents. Author: Judge Richard B. Teitelman Vote: REVERSED AND REMANDED. Russell, C.J., Fischer, Stith and Draper, JJ., concur; Wilson, J., concurs in separate opinion filed; Breckenridge, J., concurs in opinion of Wilson, J.
SC93121: Overview/Summary Travis M. Stanley, Appellant vs. State of Missouri, Respondent. Author: Judge Patricia Breckenridge Vote: AFFIRMED. All concur.
SC92996: Overview/Summary Rafael Lozano, Appellant vs. BNSF Railway Company, Respondent. Author: Judge Paul C. Wilson Vote: AFFIRMED. Russell, C.J., Breckenridge, Fischer and Stith, JJ., concur; Draper, J., dissents in separate opinion filed; Teitelman, J., concurs in opinion of Draper, J.
SC88961: Overview/Summary In re: Nathan J. Forck, Respondent. Author: Judge George W. Draper III Vote: DISCIPLINE ORDERED. Russell, C.J., Stith and Teitelman, JJ., concur; Fischer, J., dissents in separate opinion filed; Breckenridge and Wilson, JJ., concur in opinion of Fischer, J.
EDOrder-02-04-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
ED100008: Overview/Summary Karen Hidritch-Hamann, Respondent, vs. David Hidritch and Hidritch Properties, LLC, Appellants. Author: Kurt S. Odenwald, J. Vote: DISMISSED. Mary K. Hoff,P.J., and Angela T. Quigless, J., Concur.
SD32830: LINDA DORRIS, Employee-Respondent, vs. STODDARD COUNTY, Employer-Appellant. Author: Mary W. Sheffield, Judge Vote: Affirmed. Bates, P.J., and Lynch, J., Concur
SD32580: MICHAEL A. TIMBERLAKE, Appellant, vs. STATE OF MISSOURI, Respondent. Author: William W. Francis, Jr., Chief Judge Vote: Reversed and Remanded with Directions. Rahmeyer, P.J., and Scott, J., Concur
SDOrder-01-30-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
SDOrder-01-29-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
SD32783: JEFFREY BROYLES, Appellant, vs. DIRECTOR OF REVENUE, STATE OF MISSOURI, Respondent. Author: William W. Francis, Jr., Chief Judge Vote: Affirmed. Rahmeyer, P.J., and Scott, J., Concur
SD32590: CAROL BALLARD, Claimant-Respondent, v. WOODS SUPERMARKETS, INC., Employer-Appellant, and TREASURER OF THE STATE OF MISSOURI AS CUSTODIAN OF THE SECOND INJURY FUND, Respondent. Author: Jeffrey W. Bates, Presiding Judge Vote: Affirmed. Burrell, J., and Sheffield, J., Concur
WDOrder01-28-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
WD76415: Overview/Summary Darnay Session vs. Director of Revenue Author: Anthony Rex Gabbert, Judge Vote: Affirmed. Ahuja, P.J. and Newton, JJ., concur
WD76174: Overview/Summary Blythe M. Groff vs. Robert M. Groff Author: Thomas H. Newton, Judge Vote: Dismissed as moot. Ahuja, P.J. and Gabbert, JJ., concur
WD76164 and WD76165: Overview/Summary In the Matter of Kansas City Power & Light Company's Request for Authority to Implement a General Rate Increase for Electric Service vs. Midwest Energy Consumers Group; Office of Public Counsel; Missouri Public Service Commission; Dogwood Energy, Inc.; Union Electric D/B/A Ameren Missouri Author: Anthony Rex Gabbert, Judge Vote: Dismissed. Newton, P.J. and Gabbert, JJ., concur
WD76105: Overview/Summary Joseph Sanders vs. Division of Employment Security Author: Cynthia L. Martin, Presiding Judge Vote: Affirmed. Pfeiffer, JJ. and Mitchell, JJ., concur
SD32739: ST. JOHN'S CLINIC, INC., Appellant, vs. PULASKI COUNTY AMBULANCE DISTRICT, Respondent. Author: Daniel E. Scott, Judge Vote: Affirmed. Rahmeyer, P.J., Dissents in Separate Opinion, Francis, Jr., C.J., Concurs
EDOrder-01-28-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
ED99981: Overview/Summary KNT Management, LLC, Plaintiff/Appellant, vs. Kimberly Flenoid, Defendant/Respondent. Author: Lawrence E. Mooney, P.J. Vote: REVERSED AND REMANDED. Robert G. Dowd, Jr., J., and Sherri B. Sullivan, J., concur.
ED99787: Overview/Summary City of Moline Acres, Plaintiff/Appellant, vs. Charles W. Brennan, Defendant/Respondent. Author: Lisa S. Van Amburg, P.J. Vote: AFFIRMED. Patricia L. Cohen, J. and Philip M. Hess, J., concur.
ED99499: Overview/Summary In the Matter of: T.S.D. Author: Kurt S. Odenwald, J. Vote: AFFIRMED. Mary K. Hoff, P.J., and Angela T. Quigless, J., Concur.
ED99088: Overview/Summary State of Missouri, Respondent, vs. Christopher Eric Hunt, Appellant. Author: Robert G. Dowd, Jr., J. Vote: AFFIRMED IN PART AND REVERSED AND REMANDED IN PART. Lawrence E. Mooney, P.J. and Sherri B. Sullivan, J., concur.
ED98277: Overview/Summary State of Missouri, Respondent, vs. George Turner, Appellant. Author: Kurt S. Odenwald, J. Vote: AFFIRMED. Mary K. Hoff, P.J., and Angela T. Quigless J., Concur.
ED100045: Overview/Summary Rochelle Hardin, Appellant, vs. Adecco USA, Inc., Defendant/Respondent, and Biomerieux, Inc., Defendant, and Tony Dansberry, Defendant. Author: Lawrence E. Mooney, P.J. Vote: APPEAL DISMISSED. Robert G. Dowd, Jr., J., and Sherri B. Sullivan, J., concur.
SDOrder-01-27-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
SD32759 and SD32760 (Consolidated): IN THE INTEREST OF: D.T.L. and C.J.L., children under seventeen years of age. GREENE COUNTY JUVENILE OFFICE, Petitioner-Respondent, vs. V.D.L., Respondent-Appellant. Author: Nancy Steffen Rahmeyer, Presiding Judge Vote: Affirmed. Scott, J., and Lynch, J., Concur
SD32526: SANDY JACKSON, Plaintiff-Appellant, v. HAZELRIGG AUTOMOTIVE SERVICE CENTER, INC., Defendant-Respondent. Author: Jeffrey W. Bates, Presiding Judge Vote: Affirmed. Lynch, J., and Sheffield, J., Concur
ED99832: Overview/Summary State of Missouri ex rel. Arnie C. Dienoff, Respondent, vs. Patricia Galkowski, St. Charles County Ambulance District, Appellants, and Rich A. Chrismer and St. Charles County, Missouri, Defendants. Author: PER CURIAM. Vote: REVERSED AND REMANDED. Lisa S. Van Amburg, P.J., Patricia L. Cohen, J., and Gary M. Gaertner, Jr., J.
SDOrder-01-24-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
SD32858: In the Matter of KATRINA BARNES, Claimant/Appellant, vs. JASPER PRODUCTS, L.L.C., Employer/Respondent, and MISSOURI DIVISION OF EMPLOYMENT SECURITY, Respondent. Author: William W. Francis, Jr., Chief Judge Vote: Reversed and Remanded with Directions. Rahmeyer, P.J., and Scott, J., Concur
SD32800: STATE OF MISSOURI EX REL. BOB T. BEISLY II, Relator, vs. THE HONORABLE TIMOTHY PERIGO, Respondent. Author: Per Curiam Vote: Permanent Writ in Prohibition Issued. Bates, P.J., Burrell, J., and Sheffield, J., Concur
SD32562: J.T. AND A.T., BY AND THROUGH THEIR FATHER, JOHN TAYLOR, FOR THE DEATH OF THEIR MOTHER, LINDY TAYLOR, and J.T. AS PLAINTIFF AD LITEM, Plaintiffs-Appellants, vs. MARTIN ANBARI, M.D., LITTON & GIDDINGS RADIOLOGICAL ASSOCIATES, P.C., and MICHAEL WORKMAN, M.D., Defendants-Respondents. Author: Mary W. Sheffield, Judge Vote: Affirmed. Bates, P.J., and Lynch, J., Concur
SDOrder-01-22-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
WDOrder01-21-2013: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
WD75532: Overview/Summary Shawn Stevens vs. Markirk Construction, Inc. Kirk Jones and Damar Development, Inc. Author: Lisa White Hardwick, Judge Vote: Reversed & remanded. Mitchell, P.J., and Witt, JJ., concur
WD75283: Overview/Summary Terrance Robinson vs. State of Missouri Author: Joseph M. Ellis,Judge Vote: Vacated in part & remanded. Pfeiffer, P.J., and Howard, JJ., concur
WD74940: Overview/Summary Adam Dutton vs. American Family Mutual Insurance Company Author: Gary D. Witt, Judge Vote: Reversed. Ellis, JJ., Howard, JJ., Newton JJ., Pfeiffer., JJ Gabbert. JJ.,Concur, Dissenting Opinion by Judge Ahuja., Joined by Welsh, CJ., Hardwick, JJ., Mitchell, JJ., Dissenting Opinion by Judge Martin, Joined by Welsh, CJ., Hardwick, JJ., Ahuja, JJ., Mitchell, JJ
SD32620: RICHARD E. BEECHER, Appellant, vs. TERRY L. BEECHER, Respondent. Author: Daniel E. Scott, Judge Vote: Affirmed in Part, Reversed in Part, and Remanded with Directions. Rahmeyer, P.J., and Lynch, J., Concur
EDOrder-01-21-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
ED99632: Overview/Summary Charles Kyles, Appellant, vs. State of Missouri, Respondent. Author: Patricia L. Cohen, J. Vote: REVERSED AND REMANDED. Lisa S. Van Amburg, P.J., and Philip M. Hess, J., concur.
ED99569: Overview/Summary Phillip R. Sullins, Appellant, vs. Snow C. Sullins, Respondent. Author: Roy L. Richter, P.J. Vote: AFFIRM IN PART; REVERSE AND REMAND IN PART. Clifford H. Ahrens, J., and Glenn A. Norton, J., concur.
ED99553: Overview/Summary Dr. John B. Weltmer, Jr., Appellant, vs. Signature Health Services Inc. f/k/a Premier Care, Inc., St. Louis County Orthopedic Group Inc., SLCOG Property Management & Leasing Company, LLC, and Premier Care Leasing, LLC, Respondents. Author: Gary M. Gaertner, Jr., J. Vote: REVERSED IN PART AND AFFIRMED IN PART. Lisa S. Van Amburg, P.J. and Patricia L. Cohen, J., concur.
SD32683: ELIZABETH DOWNING, Employee-Respondent, vs. McDONALD'S SIRLOIN STOCKADE, Employer-Appellant. Author: Mary W. Sheffield, Judge Vote: Affirmed. Lynch, J., and Burrell, J., Concur
SD32457: TAMBRA LESTER, Petitioner-Appellant, v. DEPARTMENT OF SOCIAL SERVICES, FAMILY SUPPORT DIVISION, Respondent-Respondent. Author: Jeffrey W. Bates, Presiding Judge Vote: Affirmed. Lynch, J., and Sheffield, J., Concur
SD32413: STATE OF MISSOURI, Plaintiff-Respondent, v. BRENT LONG, Defendant-Appellant. Author: Jeffrey W. Bates, Presiding Judge Vote: Affirmed. Lynch, J., and Burrell, J., Concur
WDOrder01-14-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
WD76602 amd WD76603: Overview/Summary Gary Scott vs. Treasurer of The State of Missouri-Custodian of The Second Injury Fund Author: Mark D. Pfeiffer, Presiding Judge Vote: Reversed & remanded. Ellis, JJ. and Howard, JJ., concur
WD76509: Overview/Summary In The Matter of The Application of Laclede Gas Company D/B/A Missouri Gas Energy, For Approval to Change its Infrastructure System Replacement Surcharge; Public Service Commission of The State of Missouri vs. The Office of Public Counsel Author: James Edward Welsh, Chief Judge Presiding Vote: Affirmed. Martin, JJ. and Robb, Sp. J., concur
WD76280: Overview/Summary In The Matter of Foreclosure of Liens for Delinquent Land Taaxes By Action in Rem: Collector of Revenue, by and Through The Director of Collections for Jackson County, Missouri vs. Terry Holton, Christina McIntosh Author: Karen King Mitchell, Presiding Judge Vote: Reversed with directions. Hardwick, JJ. and Witt, JJ., concur
WD76276 and WD76347: Overview/Summary Federal National Mortgage Association and Nationstar Mortgage, LLC vs. Jeffrey A. Conover, et al Author: Mark D. Pfeiffer, Presiding Judge Vote: Reversed & remanded. Ellis, JJ. and Howard, JJ., concur
WD76068 & WD76110: Overview/Summary City of North Kansas City, Missouri vs. K.C. Beaton Holding Company, LLC, et al; Platte Valley Bank of Missouri and Keith Hicklin Author: James E. Welsh, Chief Judge Vote: Affirmed. Cross Appeal dismissed. Martin, JJ. and robb, Sp. J., concur
WD75878: Overview/Summary State of Missouri vs. Hector C. Castro Author: Gary D. Witt, Judge Vote: Dismissed as moot. Mitchell, P.J. and Hardwick, JJ., concur
SD32585: DANNY HARNESS and FAYE SAVAGE, Plaintiffs-Respondents, vs. JIM RICHARDSON, HAZEL THOMAS, BETTY NICHOLS, MIKE PRITCHETT, and RODNEY SANFORD, Defendants-Appellants. Author: Mary W. Sheffield, Judge Vote: Reversed and Remanded with Instructions. Bates, P.J., and Burrell, J., Concur
SD32563: SHERI STEPHENS, Plaintiff/Appellant, vs. SHERIFF W. ARCHIE DUNN, SHERIFF JACK L. MERRITT, RETIRED, C.E. WELLS, JOHN DOE I, JOHN DOE III, and JOHN DOE IV, Defendants/Respondents, and GERALD TUCK, JOHN DOE II, JOHN DOE V, and JOHN B. FREITAS, DO, Defendants. Author: William W. Francis, Jr., Chief Judge Vote: Affirmed. Rahmeyer, P.J., and Scott, J., Concur
SD32541: DONALD PAYNE, Claimant/Appellant, vs. TREASURER OF THE STATE OF MISSOURI, CUSTODIAN OF SECOND INJURY FUND, Respondent. Author: William W. Francis, Jr., Chief Judge Vote: Affirmed. Rahmeyer, P.J., and Scott, J., Concur
SC93340_consolidated_with_SC93345: Overview/Summary State ex rel. Amy Strauser, Relator vs. The Honorable Sandy Martinez, Respondent. (Consolidated with) State ex rel. Sharon Edmonds, Relator vs. The Honorable Sandy Martinez, Respondent. Author: Chief Justice Mary R. Russell Vote: WRITS MADE PERMANENT. Breckenridge, Stith, Draper, Wilson and Teitelman, JJ., concur; Fischer, J., concurs in separate opinion filed.
SC92984: Overview/Summary Phillip H. March, Respondent vs. Midwest St. Louis, L.L.C., Appellant. Author: Judge Patricia Breckenridge Vote: AFFIRMED. All concur.
EDOrder-01-14-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
ED99135: Overview/Summary State of Missouri, Respondent, vs. Willie Davis, Appellant. Author: Robert M. Clayton III, C.J. Vote: AFFIRMED IN PART AND REVERSED AND REMANDED IN PART. Glenn A. Norton, J. and Patricia L. Cohen, J., concur.
SDOrder-01-13-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
SD32843: IN THE INTEREST OF K.J.L., S.L.L., Appellant, vs. GREENE COUNTY JUVENILE OFFICE, Respondent. Author: Daniel E. Scott, Judge Vote: Remanded with Directions. Rahmeyer, P.J., and Francis, Jr., C.J., Concur
SD32629: ROY MEDLIN, Plaintiff/Appellant, vs. RLC, INC., Defendant/Respondent, and JEREMIAH J. HAYES, et al., Intervenors/Respondents. Author: William W. Francis, Jr., Chief Judge Vote: Affirmed. Rahmeyer, P.J., Concurs in result only; and Scott, J., Concurs.
SD32658: In the Matter of JENNA STAFFORD, Claimant/Respondent, vs. GREAT SOUTHERN BANK, Employer/Appellant, and MISSOURI DIVISION OF EMPLOYMENT SECURITY, Respondent. Author: William W. Francis, Jr., Chief Judge Vote: Reversed and Remanded with Directions. Rahmeyer, P.J., Scott, J., Concur
SDOrder-01-07-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
EDOrder-01-07-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)